@@ -37,6 +37,7 @@ from mo_future import (
     binary_type,
 )
 from mo_imports import delay_import
+
 from mo_logs.convert import (
     datetime2string,
     datetime2unix,
@@ -46,6 +47,7 @@ from mo_logs.convert import (
 )
 
 Log = delay_import("mo_logs.Log")
+json_encoder = delay_import("mo_json.encoder.json_encoder")
 Except = delay_import("mo_logs.exceptions.Except")
 Duration = delay_import("mo_times.durations.Duration")
 
@@ -185,7 +187,7 @@ def json(value, pretty=True):
     :param pretty:
     :return:
     """
-    return _json_encoder(value, pretty=pretty)
+    return json_encoder(value, pretty=pretty)
 
 
 @formatter
@@ -680,9 +682,9 @@ def toString(val):
     if val == None:
         return ""
     elif is_data(val) or is_many(val):
-        return json(val, pretty=True)
+        return json_encoder(val, pretty=True)
     elif hasattr(val, "__data__"):
-        return json(val.__data__(), pretty=True)
+        return json_encoder(val.__data__(), pretty=True)
     elif hasattr(val, "__json__"):
         return val.__json__()
     elif isinstance(val, Duration):
@@ -880,8 +882,14 @@ def apply_diff(text, diff, reverse=False, verify=True):
     return output
 
 
+WORDS = re.compile(r"[A-Z][0-9a-z]+|[A-Z][0-9A-Z]+(?=$|[^a-z])|[a-z][0-9a-z]+|[0-9][0-9]+|[0-9A-Za-z]")
+
+
 def wordify(value):
-    return [w for w in re.split(r"[\W_]", value) if strip(w)]
+    result = [w.lower() for w in WORDS.findall(value) if strip(w)]
+    if len(result) <= 1:
+        return [value]
+    return result
 
 
 def pairwise(values):
@@ -895,22 +903,3 @@ def pairwise(values):
     for b in i:
         yield (a, b)
         a = b
-
-
-def _json_encoder(value, pretty):
-    global _json_encoder
-
-    try:
-        from mo_json.encoder import json_encoder as encoder
-    except:
-        from json import dumps
-
-        def encoder(value, pretty):
-            if pretty:
-                return dumps(value, indent=4)
-
-    _json_encoder = encoder
-    return encoder(value, pretty)
-
-
-
